=======
History
=======
  
0.1.0 (2021-06-14)
------------------

* First release on PyPI.
* Added DIGGS Schema validation features.

0.1.2 (2021-06-30)
------------------

* Created a "validator" Class is  to incorperate all the validation-related methods.
* Added an argument to allow users specifiying a specific DIGGS Schema version for validation.
* Added a Schematron validation method.
* updated Documentation.